import { Component, OnInit } from '@angular/core';
import { AssignmentService } from 'services/assignment.service';
import { Assignment } from '../model/assignment';
import { ExerciseService } from 'services/exercise.service';
import { Exercise } from 'app/model/exercise';



@Component({
  selector: 'app-create-exercise',
  templateUrl: './create-exercise.component.html',
  styleUrls: ['./create-exercise.component.css']
})
export class CreateExerciseComponent implements OnInit {
  assignments: Assignment[] = [];
  selectedAssignment: Assignment | undefined; // Ajout de la variable pour stocker l'assignment sélectionné
  exerciseName: string = ''; // Ajout de la variable pour stocker le nom de l'exercice

  constructor(private assignmentService: AssignmentService, private exerciseService: ExerciseService) { }

  ngOnInit(): void {
    // Récupérer la liste des assignments lors de l'initialisation du composant
    this.assignmentService.getAssignments().subscribe(assignments => {
      this.assignments = assignments;
    });
  }

  // Méthode appelée lorsque le formulaire est soumis
  createExercise(): void {
    if (this.selectedAssignment && this.exerciseName) {
      // Créer un nouvel exercice avec les informations nécessaires
      const newExercise: Exercise = {
        id : '',
        assignmentName: this.selectedAssignment.name,
        name: this.exerciseName,
        gitlabId: 0, // Ajoutez des valeurs par défaut si nécessaire
        gitlabLink: '',
        gitlabCreationInfo: "{\"id\":14232,\"description\":\"Dojo exercise repository based on the the assignment: Technique de compilation - TP\}",
        gitlabLastInfo: '',
        gitlabLastInfoDate: this.formatDateForMySQL(new Date()),
        secret: '' // Ajoutez des valeurs par défaut si nécessaire
      };

      // Appelez le service pour créer l'exercice
      this.exerciseService.createExercise(newExercise).subscribe(response => {
        // Gérez la réponse de création si nécessaire
        console.log('Exercice créé avec succès :', response);
      });
    }
  }
  private formatDateForMySQL(date: Date): string {
    const year = date.getFullYear();
    const month = (date.getMonth() + 1).toString().padStart(2, '0');
    const day = date.getDate().toString().padStart(2, '0');
    const hours = date.getHours().toString().padStart(2, '0');
    const minutes = date.getMinutes().toString().padStart(2, '0');
    const seconds = date.getSeconds().toString().padStart(2, '0');

    return `${year}-${month}-${day} ${hours}:${minutes}:${seconds}`;
  }
}
