// exercise.component.ts

import { Component, OnInit } from '@angular/core';
import { ExerciseService } from 'services/exercise.service';
import { Exercise } from 'app/model/exercise';
import { Assignment } from 'app/model/assignment';
import { AssignmentService } from 'services/assignment.service';



@Component({
  selector: 'app-list-exercise',
  templateUrl: './list-exercise.component.html',
  styleUrls: ['./list-exercise.component.css']
})
export class ListExerciseComponent implements OnInit {
  assignmentNames: string[] = [];
  selectedAssignmentNames: string[] = [];
  exercises: Exercise[] = [];
  filteredExercises: Exercise[] = [];
  exerciseIdToDelete: string | null = null;

  constructor(
    private exerciseService: ExerciseService,
    private assignmentService: AssignmentService 
  ) {}

  ngOnInit(): void {
    
    this.exerciseService.getExercises().subscribe(exercises => {
      this.exercises = exercises;
      this.filteredExercises = this.exercises;
    });

    // Récupérer la liste des noms d'assignation lors de l'initialisation du composant
    this.assignmentService.getAssignments().subscribe(assignments => {
      this.assignmentNames = assignments.map(assignment => assignment.name);
    });
  }

  updateSelectedAssignmentNames(assignmentName: string): void {
    if (this.selectedAssignmentNames.includes(assignmentName)) {
      // Retirez l'élément si déjà présent
      this.selectedAssignmentNames = this.selectedAssignmentNames.filter(name => name !== assignmentName);
    } else {
      // Ajoutez l'élément s'il n'est pas déjà présent
      this.selectedAssignmentNames.push(assignmentName);
    }

    // Appliquez les filtres
    this.filterExercises();
  }

  filterExercises(): void {
    this.filteredExercises = this.exercises.filter(exercise =>
      this.selectedAssignmentNames.includes(exercise.assignmentName)
    );
  }

  confirmDelete(exerciseId: string): void {
    this.exerciseIdToDelete = exerciseId;
    // Ouvrir la fenêtre modale
    $('#confirmDeleteModal').modal('show');
  }

   deleteExercise(): void {
   // TODO
   $('#confirmDeleteModal').modal('hide');
  }
}