import { Injectable, OnDestroy } from '@angular/core';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Router } from '@angular/router';
import { BehaviorSubject, Subject } from 'rxjs';
import { takeUntil } from 'rxjs/operators';

@Injectable({
  providedIn: 'root'
})
export class AuthService {
  private gitLabClientId = '83846733ac6ca3d32903198198887641b4b4ff1d773d525e3e5a3d1a4be82aa5';
  private gitLabRedirectUri = 'http://localhost:4200/login';
  private gitLabAuthUrl = 'https://gitedu.hesge.ch/oauth/authorize';
  private gitLabTokenUrl = 'https://gitedu.hesge.ch/oauth/token';
  private gitLabScope = 'api+create_runner+read_repository+write_repository';
  private GITLAB_SECRET = 'gloas-1e7ffc76fdc0a8a60031d847dd0729e9c345516f8230056c776895bb93a1481e'


  private accessTokenSubject: BehaviorSubject<string | null> = new BehaviorSubject<string | null>(null);
  private refreshTokenSubject: BehaviorSubject<string | null> = new BehaviorSubject<string | null>(null);

  // Propriété pour stocker le nom d'utilisateur
  private usernameSubject: BehaviorSubject<string> = new BehaviorSubject<string>('');

  // Propriété observable pour permettre à d'autres parties de l'application d'accéder au nom d'utilisateur
  username$ = this.usernameSubject.asObservable();

   constructor(private http: HttpClient) {}

  authenticateWithGitLab(): void {
    const redirectUri = encodeURIComponent(this.gitLabRedirectUri);
    const authUrl = `${this.gitLabAuthUrl}?client_id=${this.gitLabClientId}&redirect_uri=${redirectUri}&response_type=code&scope=${this.gitLabScope}`;
    window.location.href = authUrl;
  }

  exchangeCodeForToken(code: string): void {
    const redirectUri = encodeURIComponent(this.gitLabRedirectUri);
    const body = `client_id=${this.gitLabClientId}&client_secret=${this.GITLAB_SECRET}&code=${code}&grant_type=authorization_code&redirect_uri=${redirectUri}`;
    const headers = new HttpHeaders({
      'Content-Type': 'application/x-www-form-urlencoded'
    });

    this.http.post<any>(this.gitLabTokenUrl, body, { headers }).subscribe(
      response => {
        const accessToken = response.access_token;
        const refreshToken = response.refresh_token;
        this.setAccessToken(accessToken);
        this.setRefreshToken(refreshToken);
      },
      error => {
        console.error('Erreur lors de l\'échange du code d\'autorisation contre un jeton d\'accès :', error);
      }
    );
  }
  setAccessToken(accessToken: string): void {
    localStorage.setItem('accessToken', accessToken);
    this.accessTokenSubject.next(accessToken);
    console.log('Access token stocké dans localStorage :', accessToken);
  }

  setRefreshToken(refreshToken: string): void {
    localStorage.setItem('refreshToken', refreshToken);
    this.refreshTokenSubject.next(refreshToken);
    console.log('Refresh token stocké dans localStorage :', refreshToken);
  }

  getAccessToken(): string | null {
    const accessToken = localStorage.getItem('accessToken');
    console.log('Access token récupéré depuis localStorage :', accessToken);
    return accessToken;
  }

  getRefreshToken(): string | null {
    const refreshToken = localStorage.getItem('refreshToken');
    console.log('Refresh token récupéré depuis localStorage :', refreshToken);
    return refreshToken;
  
  }

  clearAccessToken(): void {
    localStorage.removeItem('accessToken');
    this.accessTokenSubject.next(null);
    console.log('Access token supprimé de localStorage.');
  }

  clearRefreshToken(): void {
    localStorage.removeItem('refreshToken');
    this.refreshTokenSubject.next(null);
    console.log('Refresh token supprimé de localStorage.');
  }
}