import { Injectable } from '@angular/core';
import { HttpClient, HttpParams, HttpHeaders } from '@angular/common/http';;
import { Observable } from 'rxjs';
import { Exercise } from '../app/model/exercise'; 
import { Assignment } from '../app/model/assignment';
import { AuthService } from './auth_service';
import { Result } from 'app/model/result';

@Injectable({
  providedIn: 'root'
})

export class ExerciseService {
  private baseUrl = 'http://localhost:3000';

  constructor(private http: HttpClient) {}

  getExercises(): Observable<Exercise[]> {
    return this.http.get<Exercise[]>(`${this.baseUrl}/exercises`);
  }


  getAssignments(): Observable<Assignment[]> {
    return this.http.get<Assignment[]>(`${this.baseUrl}/assignments`);
  }

  getExercisesByAssignmentName(assignmentName: string): Observable<Exercise[]> {
    return this.http.get<Exercise[]>(`${this.baseUrl}/exercises?assignmentName=${assignmentName}`);
  }

  getResults(): Observable<Result[]> {
    return this.http.get<Result[]>(`${this.baseUrl}/results`);
  }

  getExerciseById(id: string): Observable<Exercise> {
  console.log('ID de l\'exercice demandé :', id);

  return this.http.get<Exercise>(`${this.baseUrl}/exercises/${id}`);
  }

  getExercisesByName(name: string): Observable<Exercise[]> {
    // Utilisez HttpParams pour ajouter le paramètre de filtrage par nom
    const params = new HttpParams().set('name', name);

    // Utilisez les paramètres dans la requête HTTP
    return this.http.get<Exercise[]>(`${this.baseUrl}/exercises`, { params });
  }
  // Méthode pour créer un nouvel exercice
  createExercise(exercise: Exercise): Observable<any> {
    return this.http.post(`${this.baseUrl}/exercises`, exercise);
  }
}

// export class ExerciseService {
//   private baseUrl = 'http://localhost:30993';

//   constructor(private http: HttpClient, private authService: AuthService) {}

//   setAccessToken(token: string): void {
//     this.authService.setAccessToken(token);
//   }
  

//  getExercises(): Observable<Exercise[]> {
//     return this.http.get<Exercise[]>(`${this.baseUrl}/exercises`, {
//       headers: this.getHeadersWithToken() 
//     });
//   }

//   getAssignments(): Observable<Assignment[]> {
//     return this.http.get<Assignment[]>(`${this.baseUrl}/assignments`, {
//       headers: this.getHeadersWithToken()
//     });
//   }

//   getExercisesByAssignmentName(assignmentName: string): Observable<Exercise[]> {
//     return this.http.get<Exercise[]>(`${this.baseUrl}/exercises?assignmentName=${assignmentName}`, {
//       headers: this.getHeadersWithToken() 
//     });
//   }
//   getExerciseById(id: string): Observable<Exercise> {
//   console.log('ID de l\'exercice demandé :', id);

//   return this.http.get<Exercise>(`${this.baseUrl}/exercises/${id}`);
// }

//   getExercisesByName(name: string): Observable<Exercise[]> {
//     // Utilisez HttpParams pour ajouter le paramètre de filtrage par nom
//     const params = new HttpParams().set('name', name);

//     // Utilisez les paramètres dans la requête HTTP
//     return this.http.get<Exercise[]>(`${this.baseUrl}/exercises`, { params });
//   }
//   // Méthode pour créer un nouvel exercice
//   createExercise(exercise: Exercise): Observable<any> {
//     return this.http.post(`${this.baseUrl}/exercises`, exercise);
//   }

//   private getHeadersWithToken(): HttpHeaders {
//     const token = this.authService.getAccessToken();
//     return new HttpHeaders({
//       'Authorization': `Bearer ${token}`
//     });
//   }
// }
